==> image-editor_1.0.11.orig.tar.xz: image-editor-1.0.11/libimageviewer/translations/libimageviewer_gl_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="gl_ES" version="2.1">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Información da imaxe</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Información básica</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Engadir ao álbum</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novo álbum</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Todas as imaxes</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Abrir imaxe</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Eliminar do álbum</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Quitar das favoritas</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Poñer nas favoritas</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Non tes permiso para ver a imaxe</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Data da modificación</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Tamaño do ficheiro</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Data de captura</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Modo de exposición</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programa de exposición</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Tempo de exposición</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Apertura</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Distancia focal</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Máxima apertura</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Modo de medición</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balance de brancos</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensación de flash</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Modelo de lente</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Espazo de cor</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Modelo de cámara</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensións</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Etiqueta</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Posterior</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 Tamaño</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Axustar á xanela</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Xire en sentido antihorario</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Xira en sentido horario</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Saír da pantalla completa</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentación</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Amosar xanela de navegación</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Ocultar xanela de navegación</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Establecer como fondo de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Visualizar no xestor de ficheiros</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Información da imaxe</translation>
    </message>
    <message>
        <source>day</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Poña un novo nome</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Posterior</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Saír</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Non se atoparon ficheiros de imaxe</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Non se atopou a imaxe</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> image-editor_1.0.39.orig.tar.xz: image-editor-1.0.39/libimageviewer/translations/libimageviewer_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Información da imaxe</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Información básica</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Engadir ao álbum</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novo álbum</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Todas as imaxes</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Abrir imaxe</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Eliminar do álbum</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Quitar das favoritas</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Poñer nas favoritas</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Non tes permiso para ver a imaxe</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Data da modificación</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Tamaño do ficheiro</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Data de captura</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Modo de exposición</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programa de exposición</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Tempo de exposición</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Apertura</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Distancia focal</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Máxima apertura</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Modo de medición</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balance de brancos</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensación de flash</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Modelo de lente</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Espazo de cor</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Modelo de cámara</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensións</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Etiqueta</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Posterior</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 Tamaño</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Axustar á xanela</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Xire en sentido antihorario</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Xira en sentido horario</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Saír da pantalla completa</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentación</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Amosar xanela de navegación</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Ocultar xanela de navegación</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Establecer como fondo de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Visualizar no xestor de ficheiros</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Información da imaxe</translation>
    </message>
    <message>
        <source>day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Poña un novo nome</translation>
    </message>
    <message>
        <source>The file already exists, please use another name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Posterior</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Saír</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Non se atoparon ficheiros de imaxe</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Non se atopou a imaxe</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
